from setuptools import setup, find_packages

setup(
    name="zsafe",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[
        "zstandard",
        "cryptography",
    ],
    author="Amin Rezaei",
    author_email="amin.zdev@gmail.com",
    description="A lightweight CLI tool for compressing, "
                "encrypting, and backing up directories "
                "to Telegram & Google Drive.",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/aminzdev/zsafe",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "Operating System :: POSIX :: Linux",
    ],
    python_requires=">=3.6",
    license="GPL-2.0-only",
    entry_points={
        'console_scripts': [
            'zsafe=zsafe.cli:main',
        ],
    },
)